@@ -6,7 +6,7 @@ import os
 from oss2.exceptions import NoSuchKey,NoSuchBucket
 import json
 from ..const import WIN,PY2
-
+import time
 SLEN = 60
 
 def fetch(jobId, dir_path=None,stdout=False, stderr=False, log_mapping=False, taskName=None, instanceId=None):
@@ -14,12 +14,8 @@ def fetch(jobId, dir_path=None,stdout=False, stderr=False, log_mapping=False, ta
     if jobId.startswith('-'):
         raise Exception('Invalid jobId')
 
-
-
     jobId = result_cache.get(jobId, 'jobs')
 
-
-
     t = [jobId]
     if taskName:
         taskName = result_cache.get(taskName, 'tasks')
@@ -125,6 +121,7 @@ def print_inst_result(jobId, taskName, ins, dir_path):
 def print_ins_log(jobId, taskName, ins, stdout, stderr, log_mapping, dir_path):
 
     oss_path_arr = __get_ins_oss_path(jobId, taskName, ins, stdout, stderr, log_mapping)
+
     if dir_path:
         for oss_path in oss_path_arr:
             download_log(oss_path, dir_path)
@@ -148,11 +145,13 @@ def __get_ins_oss_path(jobId, taskName , ins, stdout, stderr, log_mapping):
         elif log_mapping:
             jobDesc = client.get_job_description(jobId)
             jobDesc = formater.to_dict(jobDesc)
-            m = jobDesc['DAG']['Tasks'][taskName]['LogMapping']
-            for localPath, ossDir in m.items():
-                t.append('%s%s.%s.%s.%s' % (ossDir, os.path.basename(localPath), jobId, taskName, instanceId))
 
+            if jobDesc['Type']=='DAG':
+                m = jobDesc['DAG']['Tasks'][taskName]['LogMapping']
+                for localPath, ossDir in m.items():
+                    t.append('%s%s.%s.%s.%s' % (ossDir, os.path.basename(localPath), jobId, taskName, instanceId))
 
+            #else: App
     else:
         # all
         stdout_path = formater.fix_log_path(ins['StdoutRedirectPath'], jobId, taskName, instanceId, 'stdout')
@@ -162,17 +161,21 @@ def __get_ins_oss_path(jobId, taskName , ins, stdout, stderr, log_mapping):
 
         jobDesc = client.get_job_description(jobId)
         jobDesc = formater.to_dict(jobDesc)
-        m = jobDesc['DAG']['Tasks'][taskName]['LogMapping']
-        for localPath, ossDir in m.items():
-            t.append('%s%s.%s.%s.%s' % (ossDir, os.path.basename(localPath), jobId, taskName, instanceId))
+
+        if jobDesc['Type'] == 'DAG':
+            m = jobDesc['DAG']['Tasks'][taskName]['LogMapping']
+            for localPath, ossDir in m.items():
+                t.append('%s%s.%s.%s.%s' % (ossDir, os.path.basename(localPath), jobId, taskName, instanceId))
 
     return t
 
 
 def print_log(taskName, instId, oss_path):
+
     try:
         #file_name = oss_path[oss_path.rfind('/')+1:]
         h = oss_client.head_data(oss_path)
+
         if h.content_length > 1* 1024*1024:
             print('''\n  Log file is too large to preview(size=%s), you can use 'bcs o cat -h' to preview or download it manually\n  %s\n''' % (h.content_length, oss_path))
             return
