@@ -8,7 +8,15 @@ CMD = 'bcs'
 LOCALE_SUPPORTED = ['en', 'zh', 'zh_CN']
 
 
-VERSION = '1.5.2'
+VERSION = '1.5.3'
+
+TEMPLATE_GATK_BUCKETS = {
+'cn-beijing': 'genomics-public-data-beijing',
+'cn-qingdao': 'genomics-public-data-qingdao',
+'cn-shenzhen': 'genomics-public-data-shenzhen',
+'cn-hangzhou': 'genomics-public-data-hangzhou',
+'cn-shanghai': 'genomics-public-data-shanghai',
+}
 
 
 EVENTS = {
